==> citrus-spring-4.0.2-sources.jar: org/citrusframework/model/testcase/core/PlsqlModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.core;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für PlsqlActionType complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType name="PlsqlActionType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://www.citrusframework.org/schema/testcase}description" minOccurs="0"/>
 *         <choice>
 *           <element name="resource">
 *             <complexType>
 *               <complexContent>
 *                 <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                   <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                 </restriction>
 *               </complexContent>
 *             </complexType>
 *           </element>
 *           <element name="script" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         </choice>
 *       </sequence>
 *       <attribute name="datasource" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="transaction-manager" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="transaction-timeout" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="transaction-isolation-level" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="ignore-errors" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PlsqlActionType", propOrder = {
    "description",
    "script",
    "resource"
})
@XmlRootElement(name = "plsql")
public class PlsqlModel {

    protected String description;
    protected String script;
    protected PlsqlModel.Resource resource;
    @XmlAttribute(name = "datasource", required = true)
    protected String datasource;
    @XmlAttribute(name = "transaction-manager")
    protected String transactionManager;
    @XmlAttribute(name = "transaction-timeout")
    protected String transactionTimeout;
    @XmlAttribute(name = "transaction-isolation-level")
    protected String transactionIsolationLevel;
    @XmlAttribute(name = "ignore-errors")
    protected String ignoreErrors;

    /**
     * Ruft den Wert der description-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * Legt den Wert der description-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Ruft den Wert der script-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getScript() {
        return script;
    }

    /**
     * Legt den Wert der script-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setScript(String value) {
        this.script = value;
    }

    /**
     * Ruft den Wert der resource-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link PlsqlModel.Resource }
     *     
     */
    public PlsqlModel.Resource getResource() {
        return resource;
    }

    /**
     * Legt den Wert der resource-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link PlsqlModel.Resource }
     *     
     */
    public void setResource(PlsqlModel.Resource value) {
        this.resource = value;
    }

    /**
     * Ruft den Wert der datasource-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDatasource() {
        return datasource;
    }

    /**
     * Legt den Wert der datasource-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDatasource(String value) {
        this.datasource = value;
    }

    /**
     * Ruft den Wert der transactionManager-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTransactionManager() {
        return transactionManager;
    }

    /**
     * Legt den Wert der transactionManager-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTransactionManager(String value) {
        this.transactionManager = value;
    }

    /**
     * Ruft den Wert der transactionTimeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTransactionTimeout() {
        return transactionTimeout;
    }

    /**
     * Legt den Wert der transactionTimeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTransactionTimeout(String value) {
        this.transactionTimeout = value;
    }

    /**
     * Ruft den Wert der transactionIsolationLevel-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTransactionIsolationLevel() {
        return transactionIsolationLevel;
    }

    /**
     * Legt den Wert der transactionIsolationLevel-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTransactionIsolationLevel(String value) {
        this.transactionIsolationLevel = value;
    }

    /**
     * Ruft den Wert der ignoreErrors-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIgnoreErrors() {
        return ignoreErrors;
    }

    /**
     * Legt den Wert der ignoreErrors-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIgnoreErrors(String value) {
        this.ignoreErrors = value;
    }


    /**
     * <p>Java-Klasse für anonymous complex type.
     * 
     * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Resource {

        @XmlAttribute(name = "file", required = true)
        protected String file;

        /**
         * Ruft den Wert der file-Eigenschaft ab.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getFile() {
            return file;
        }

        /**
         * Legt den Wert der file-Eigenschaft fest.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setFile(String value) {
            this.file = value;
        }

    }

}

==> citrus-spring-4.1.0-sources.jar: org/citrusframework/model/testcase/core/PlsqlModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.core;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für PlsqlActionType complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType name="PlsqlActionType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://www.citrusframework.org/schema/testcase}description" minOccurs="0"/>
 *         <choice>
 *           <element name="resource">
 *             <complexType>
 *               <complexContent>
 *                 <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                   <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                 </restriction>
 *               </complexContent>
 *             </complexType>
 *           </element>
 *           <element name="script" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         </choice>
 *       </sequence>
 *       <attribute name="datasource" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="transaction-manager" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="transaction-timeout" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="transaction-isolation-level" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="ignore-errors" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PlsqlActionType", propOrder = {
    "description",
    "script",
    "resource"
})
@XmlRootElement(name = "plsql")
public class PlsqlModel {

    protected String description;
    protected String script;
    protected PlsqlModel.Resource resource;
    @XmlAttribute(name = "datasource", required = true)
    protected String datasource;
    @XmlAttribute(name = "transaction-manager")
    protected String transactionManager;
    @XmlAttribute(name = "transaction-timeout")
    protected String transactionTimeout;
    @XmlAttribute(name = "transaction-isolation-level")
    protected String transactionIsolationLevel;
    @XmlAttribute(name = "ignore-errors")
    protected String ignoreErrors;

    /**
     * Ruft den Wert der description-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * Legt den Wert der description-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Ruft den Wert der script-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getScript() {
        return script;
    }

    /**
     * Legt den Wert der script-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setScript(String value) {
        this.script = value;
    }

    /**
     * Ruft den Wert der resource-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link PlsqlModel.Resource }
     *     
     */
    public PlsqlModel.Resource getResource() {
        return resource;
    }

    /**
     * Legt den Wert der resource-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link PlsqlModel.Resource }
     *     
     */
    public void setResource(PlsqlModel.Resource value) {
        this.resource = value;
    }

    /**
     * Ruft den Wert der datasource-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDatasource() {
        return datasource;
    }

    /**
     * Legt den Wert der datasource-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDatasource(String value) {
        this.datasource = value;
    }

    /**
     * Ruft den Wert der transactionManager-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTransactionManager() {
        return transactionManager;
    }

    /**
     * Legt den Wert der transactionManager-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTransactionManager(String value) {
        this.transactionManager = value;
    }

    /**
     * Ruft den Wert der transactionTimeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTransactionTimeout() {
        return transactionTimeout;
    }

    /**
     * Legt den Wert der transactionTimeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTransactionTimeout(String value) {
        this.transactionTimeout = value;
    }

    /**
     * Ruft den Wert der transactionIsolationLevel-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTransactionIsolationLevel() {
        return transactionIsolationLevel;
    }

    /**
     * Legt den Wert der transactionIsolationLevel-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTransactionIsolationLevel(String value) {
        this.transactionIsolationLevel = value;
    }

    /**
     * Ruft den Wert der ignoreErrors-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIgnoreErrors() {
        return ignoreErrors;
    }

    /**
     * Legt den Wert der ignoreErrors-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIgnoreErrors(String value) {
        this.ignoreErrors = value;
    }


    /**
     * <p>Java-Klasse für anonymous complex type.</p>
     * 
     * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Resource {

        @XmlAttribute(name = "file", required = true)
        protected String file;

        /**
         * Ruft den Wert der file-Eigenschaft ab.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getFile() {
            return file;
        }

        /**
         * Legt den Wert der file-Eigenschaft fest.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setFile(String value) {
            this.file = value;
        }

    }

}
